#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-LeT2ktaJdH62xlttOS1KCX
key:                  lsp-2.2.0.0-LeT2ktaJdH62xlttOS1KCX
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  0a5154f2e9fca3c3765285f7b66a63de
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-DpvzDLtcgSBBvlBvGjI3wc:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-DpvzDLtcgSBBvlBvGjI3wc:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-DpvzDLtcgSBBvlBvGjI3wc:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-DpvzDLtcgSBBvlBvGjI3wc:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-LeT2ktaJdH62xlttOS1KCX
depends:
    aeson-2.2.1.0-KqVneGNcXEJ8mIL8sTS8LL
    async-2.2.6-HlTb8qs1wHD7UNlnrqlxTX
    attoparsec-0.14.4-8ZKlPX7xLQdALFlvUv2KV7 base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-GameCk3DRIwBK5JIq8EIM7
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-3mscVqjFvnNHNJmw9rQ9m6
    lens-5.3.4-59xiJiOdHtvHZvlFC0zvFo
    lens-aeson-1.2.3-FMFj689KTwD1uN50DRtoOh
    lsp-types-2.0.2.0-DpvzDLtcgSBBvlBvGjI3wc mtl-2.3.1
    prettyprinter-1.7.1-2nVenIIUlIN10A4pxpSujW
    random-1.2.1.3-Lrunn7lr3eYBt1jhWQyV5S
    row-types-1.0.1.2-3Hy5vinNygFLcq9sES7JOT
    sorted-list-0.2.3.1-2rElE3uIFmU5e6hZnU6umm stm-2.5.1.0
    temporary-1.3-EZyCN0IpTQNJIMCpUwiknJ text-2.0.2
    text-rope-0.3-7aPOTM1xmqdIhyvkI25VZg transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh
    uuid-1.3.16.1-LPn4sTwNkraH5uW9TWCwGS

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

